import 'package:bluetooth_manager/models/bluetooth_models.dart';
import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:bluetooth_manager/bluetooth_manager.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  late BluetoothState _bluetoothState = BluetoothState.uknow;

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    // We also handle the message potentially returning null.
    try {
      platformVersion =
          await BluetoothManager.platformVersion ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            children: [
              Text('Running on: $_platformVersion\n'),
              Text('Bluetooth State: $_bluetoothState\n'),
              ElevatedButton(
                onPressed: () async {
                  await BluetoothManager.getBluetoothState
                      .then((value) async => {
                            setState(() {
                              _bluetoothState = value!;
                            }),
                          });
                },
                child: const Text('Get bluetooth State'),
              ),
              ElevatedButton(
                onPressed: () async {
                  if (_bluetoothState == BluetoothState.on) {
                    await BluetoothManager.disableBluetooth().then(
                      (value) => {
                        print(value),
                      },
                    );
                  } else {
                    await BluetoothManager.enableBluetooth().then(
                      (value) => {
                        print(value),
                      },
                    );
                  }
                },
                child: const Text('Turn on/off'),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
